// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.navigator.handler;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IHandler;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.TreeSelection;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorReference;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.api.service.config.TaxonDeletionConfigurator;
import eu.etaxonomy.cdm.model.common.ITreeNode;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.ITaxonTreeNode;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.editor.TaxonEditorInput;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;
import eu.etaxonomy.taxeditor.navigation.navigator.TaxonNavigator;
import eu.etaxonomy.taxeditor.navigation.navigator.operation.DeleteOperation;
import eu.etaxonomy.taxeditor.operation.AbstractPostOperation;

/**
 * <p>DeleteTreeNodeHandler class.</p>
 *
 * @author n.hoffmann
 * @created 06.04.2009
 * @version 1.0
 */
public class DeleteHandler extends AbstractHandler implements IHandler{

	protected IWorkbenchPage activePage;
	protected TaxonNavigator taxonNavigator;

	/** {@inheritDoc} */
	@Override
    public Object execute(ExecutionEvent event) throws ExecutionException {

		activePage = HandlerUtil.getActiveWorkbenchWindow(event).getActivePage();

		taxonNavigator = NavigationUtil.showNavigator();

		TreeSelection selection = (TreeSelection) HandlerUtil.getCurrentSelection(event);

		String plural = selection.size() > 1 ? "s" : "";
		// Prompt user for confirmation
		
		

		Iterator selectionIterator = selection.iterator();
		Set<ITaxonTreeNode> treeNodes = new HashSet<ITaxonTreeNode>();

		while (selectionIterator.hasNext()){
			Object object = selectionIterator.next();
			if(object instanceof ITaxonTreeNode) {
                treeNodes.add((ITaxonTreeNode) object);
            }
		}
		boolean allEditorsClosed = true;
		for (ITaxonTreeNode treeNode : treeNodes){
			if(treeNode instanceof TaxonNode) {
				allEditorsClosed &= closeObsoleteEditor((TaxonNode) treeNode);
			}
		}
		AbstractPostOperation operation = null;
		if (treeNodes.size() == 1 ){
			try {
				
				ITaxonTreeNode treeNode = treeNodes.iterator().next();
				ITaxonTreeNode taxonNode =treeNode;
				
				if (taxonNode instanceof Classification && taxonNode.hasChildNodes()){
					if(! MessageDialog.openConfirm(HandlerUtil.getActiveShell(event), "Confirm Deletion", "Do you really want to delete the classification? The tree has children, they will be deleted, too")){
						return null;
					}
				} else if (taxonNode instanceof Classification && !taxonNode.hasChildNodes()){
					if(! MessageDialog.openConfirm(HandlerUtil.getActiveShell(event), "Confirm Deletion", "Do you really want to delete the classification?")){
						return null;
					}
				} else {
					if(! MessageDialog.openConfirm(HandlerUtil.getActiveShell(event), "Confirm Deletion", "Do you really want to delete the selected node?")){
						return null;
					}
				}
	
				if (allEditorsClosed){
					/*if(! MessageDialog.openConfirm(HandlerUtil.getActiveShell(event), "Confirm Deletion", "Do you really want to delete the selected nodes?")){
						return null;
					}*/
						operation = new DeleteOperation(
								event.getCommand().getName(), NavigationUtil.getUndoContext(),
								taxonNode, new TaxonDeletionConfigurator(), taxonNavigator, taxonNavigator);
			
						NavigationUtil.executeOperation(operation);
						//}
				}
	
		
	
			} catch (NotDefinedException e) {
				MessagingUtils.warn(getClass(), "Command name not set");
			}
		} else{
			try{
				if(! MessageDialog.openConfirm(HandlerUtil.getActiveShell(event), "Confirm Deletion", "Do you really want to delete the selected nodes?")){
					return null;
				}
				if (allEditorsClosed){
					operation = new DeleteOperation(
							event.getCommand().getName(), NavigationUtil.getUndoContext(),
							treeNodes, new TaxonDeletionConfigurator(), taxonNavigator, taxonNavigator);
		
					NavigationUtil.executeOperation(operation);
				}
			}catch (NotDefinedException e) {
				MessagingUtils.warn(getClass(), "Command name not set");
			}
		}
		return null;
	}

	protected boolean closeObsoleteEditor(TaxonNode taxonNode){
		boolean result = true;
		for (IEditorReference ref : activePage.getEditorReferences()) {
			try {
				String treeIndex = ((ITreeNode)taxonNode).treeIndex();
				
				
				IEditorInput input = ref.getEditorInput();
				if (input instanceof TaxonEditorInput) {
					TaxonNode node = ((TaxonEditorInput) input).getTaxonNode();
					//if node is a child of taxonNode then close the editor
					if( ((ITreeNode) node).treeIndex().startsWith(treeIndex)){
					//if (taxonNode.equals(node)) {
						result &= activePage.closeEditor(ref.getEditor(false), true);
						
					}
				}
			} catch (PartInitException e) {
				continue;
			}
		}
		return result;
	}
}
